Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(537)

Unified Diff: components/autofill/core/browser/personal_data_manager.h

Issue 2625413002: [Payments] Update metadata instead of billing address for server cards. (Closed)
Patch Set: Addressed comments Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/core/browser/personal_data_manager.h
diff --git a/components/autofill/core/browser/personal_data_manager.h b/components/autofill/core/browser/personal_data_manager.h
index 239c88d6cc52b94bc8f4cc18bfe0c5d4cdf39b92..aac237b4047396eb65ee47efe580318b9c16378d 100644
--- a/components/autofill/core/browser/personal_data_manager.h
+++ b/components/autofill/core/browser/personal_data_manager.h
@@ -152,9 +152,9 @@ class PersonalDataManager : public KeyedService,
// status can be changed. Looks up the card by server ID.
virtual void UpdateServerCreditCard(const CreditCard& credit_card);
- // Updates the billing address for the server |credit_card|. Looks up the card
- // by GUID.
- void UpdateServerCardBillingAddress(const CreditCard& credit_card);
+ // Updates the metadata for the server |credit_card|. Looks up the card by
please use gerrit instead 2017/01/13 14:31:09 specify exactly the data that's going to be update
sebsg 2017/01/13 20:23:58 Done.
+ // server_id.
+ void UpdateServerCardMetadata(const CreditCard& credit_card);
// Resets the card for |guid| to the masked state.
void ResetFullServerCard(const std::string& guid);

Powered by Google App Engine
This is Rietveld 408576698